# API Reference

## Jabberjay

::: Jabberjay.jabberjay.Jabberjay

---

## DetectionResult

::: Jabberjay.jabberjay.DetectionResult

---

## Enums

### Model

::: Jabberjay.Utilities.enum_handler.Model

### Dataset

::: Jabberjay.Utilities.enum_handler.Dataset

### Visualisation

::: Jabberjay.Utilities.enum_handler.Visualisation
